/**
 * Copyright(C) 2013 Patrik Dufresne Service Logiciel <info@patrikdufresne.com>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.planimod.ui.views.qualifs;

import static com.planimod.ui.Localized._;

import org.eclipse.jface.dialogs.InputDialog;
import org.eclipse.jface.operation.IRunnableContext;
import org.eclipse.jface.window.IShellProvider;
import org.eclipse.jface.window.Window;
import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Display;

import com.patrikdufresne.managers.ManagerException;
import com.patrikdufresne.printing.IPrintFactory;
import com.patrikdufresne.printing.PrintAction;
import com.planimod.core.ApplicationSetting;
import com.planimod.core.PlanimodManagers;
import com.planimod.ui.PlanimodPolicy;
import com.planimod.ui.preference.PlanimodPreferences;
import com.planimod.ui.printing.PlanimodPrintFactory;

/**
 * This action intend to print the qualification.
 * 
 * @author patapouf
 * 
 */
public class QualificationPrintAction extends PrintAction {
    /**
     * Define the preference key for this action
     */
    private static final String PREF_KEY = "QualificationPrintAction.printPreference";

    /**
     * Managers to use.
     */
    private PlanimodManagers managers;

    private String rev;

    /**
     * Create a new Print Employee Action
     * 
     * @param shell
     *            A Shell provider used to create new windows
     * @param operation
     *            type of operation : PRINT or PREVIEW
     */
    public QualificationPrintAction(PlanimodManagers managers, IShellProvider shell, int operation, IRunnableContext context) {
        super(shell, new QualificationPrintFactory(), operation, context);
        if (managers == null) {
            throw new IllegalArgumentException();
        }
        this.managers = managers;
        setPrefKey(PREF_KEY);
        setPreferenceStore(PlanimodPreferences.getPreferenceStore());
        setEnabled(true);
        if (operation == PrintAction.PRINT_ACTION) {
            setText(_("Imprimer grille de formation"));
        } else {
            setText(_("Aperçu avant impression"));
        }
    }

    /**
     * Returns the managers used by this action.
     * 
     * @return
     */
    protected PlanimodManagers getManagers() {
        return this.managers;
    }

    /**
     * This implementation set the employee to print
     * 
     * @param factory
     *            the factory
     */
    @Override
    protected void initFactory(IPrintFactory factory) {

        QualificationPrintFactory qualifPrintFactory = (QualificationPrintFactory) factory;
        qualifPrintFactory.setOrientation(SWT.HORIZONTAL);
        try {
            // Sets subtitle
            String customerName = getManagers().getApplicationSettingManager().getByName(ApplicationSetting.CUSTOMER_NAME);
            ((PlanimodPrintFactory) factory).setSubTitle(customerName);

            // Sets the employees
            qualifPrintFactory.setEmployeePreferences(getManagers().getEmployeePreferenceManager().list());

            // Sets the qualifications
            qualifPrintFactory.setQualifications(getManagers().getQualificationManager().list());

            // Sets the revision number
            qualifPrintFactory.setRevision(this.rev);
        } catch (ManagerException e) {
            PlanimodPolicy.showException(e);
        }
    }

    @Override
    public void run() {
        // Prompt the user for a revision number
        InputDialog dlg = new InputDialog(
                getShellProvider().getShell(),
                Display.getAppName(),
                _("Entrez un numéro de révision.\nPour l'impression de ce rapport, il est nécéssaire de saisir un numéro de réfivision. "),
                this.rev,
                null);
        if (Window.OK != dlg.open()) {
            return;
        }
        this.rev = dlg.getValue();
        super.run();
    }
}
